@@ -1,13 +1,17 @@
+"""Script containing util functions for 3aransia"""
+
 import re
 import csv
-import collections
 
-import pandas as pd
-
-from aaransia.defaults import *
+from aaransia.defaults import BASE_DIR, DATA_DIR, ALPHABET_FILE
 
 # Remove noise from arabic text
 def de_noise(text):
+    """Returns a de-noised arabic text
+
+    Keyword arguments:
+    @text -- the text to de-noise
+    """
     noise = re.compile(""" ّ    | # Tashdid
                              َ    | # Fatha
                              ً    | # Tanwin Fath
@@ -23,15 +27,23 @@ def de_noise(text):
 
 # Normalize arabic
 def normalize_arabic(text):
+    """Returns a normalized arabic text
+
+    Keyword arguments:
+    @text -- the text to normalize
+    """
     text = re.sub("[إأٱآا]", "ا", text)
-    text = re.sub("ى", "ي", text)
+    text = re.sub("ى", "ا", text)
     text = re.sub("ؤ", "ء", text)
     text = re.sub("ئ", "ء", text)
-    return(text)
+    return text
 
 # Construct alphabet dictionary
 def construct_alphabet():
-    with open(BASE_DIR + DATA_DIR + ALPHABET) as fh:
-        rd, alphabet = csv.DictReader(fh, delimiter=','), list()
-        for row in rd: alphabet.append(row)
-        return alphabet
\ No newline at end of file
+    """Returns the constructed alphabet from the csv file in data
+    """
+    with open(BASE_DIR + DATA_DIR + ALPHABET_FILE) as file_handler:
+        dict_reader, alphabet = csv.DictReader(file_handler, delimiter=','), list()
+        for row in dict_reader:
+            alphabet.append(row)
+        return alphabet
